Struct conjure_codegen::Config

source ·
pub struct Config { /* private fields */ }
Codegen configuration.

Implementations

source

impl Config

source

pub fn new() -> Config

Creates a new Config with default settings.

source

pub fn exhaustive(&mut self, exhaustive: bool) -> &mut Config

Controls exhaustive matchability of unions and enums.

Non-exhaustive unions and enums have the ability to deserialize and reserialize unknown variants. This enables clients to be more forward-compatible with changes made by newer servers.

Defaults to false.

source

pub fn staged_builders(&mut self, staged_builders: bool) -> &mut Config

If enabled, generated objects will use “staged builders”.

Staged builders guarantee that all fields are set at compile time rather than panicing during construction.

Defaults to false.

source

pub fn run_rustfmt(&mut self, _run_rustfmt: bool) -> &mut Config

👎Deprecated since 1.2.0: no longer used

No longer used.

source

pub fn rustfmt<T>(&mut self, _rustfmt: T) -> &mut Configwhere T: AsRef<OsStr>,

👎Deprecated since 1.2.0: no longer used

No longer used.

source

pub fn strip_prefix<T>(&mut self, strip_prefix: T) -> &mut Configwhere T: Into<Option<String>>,

Sets a prefix that will be stripped from package names.

Defaults to None.

source

pub fn version<T>(&mut self, version: T) -> &mut Configwhere T: Into<Option<String>>,

Sets the version included in endpoint metadata for generated client bindings.

Defaults to the version passed to Self::build_crate, or None otherwise.

source

pub fn build_crate(&mut self, name: &str, version: &str) -> &mut Config

Switches generation to create a full crate.

Defaults to just generating a single module.

source

pub fn generate_files<P, Q>(&self, ir_file: P, out_dir: Q) -> Result<(), Error>where P: AsRef<Path>, Q: AsRef<Path>,

Generates Rust source files from a JSON-encoded Conjure IR file.